KeyTable example - Server-side processing

# KeyTable example Server-side processing

KeyTable fully supports DataTables server-side processing mode which can be used to display a DataTable that contains thousands or millions of records.

The interaction options of KeyTable operate in exactly the same way for server-side processing, as shown in this example (try using the arrow keys to move focus from one page to another for example).

First name | Last name | Position | Office | Start date | Salary
--- | --- | --- | --- | --- | ---
First name | Last name | Position | Office | Start date | Salary

- Javascript
- HTML
- CSS
- Ajax
- Server-side script

The Javascript shown below is used to initialise the table shown in this example:

`$(document).ready(function() { $('#example').DataTable( { serverSide: true, ajax: "../../../../examples/server_side/scripts/server_processing.php", keys: true } ); } );`

In addition to the above code, the following Javascript library files are loaded for use in this example:

- //code.jquery.com/jquery-1.12.4.js
- ../../../../media/js/jquery.dataTables.js
- ../../js/dataTables.keyTable.js

The HTML shown below is the raw HTML table element, before it has been enhanced by DataTables:

This example uses a little bit of additional CSS beyond what is loaded from the library files (below), in order to correctly display the table. The additional CSS used is shown below:

``

The following CSS library files are loaded for use in this example to provide the styling of the table:

- ../../../../media/css/jquery.dataTables.css
- ../../css/keyTable.dataTables.css

This table loads data by Ajax. The latest data that has been loaded is shown below. This data will update automatically as any additional data is loaded.

The script used to perform the server-side processing for this table is shown below. Please note that this is just an example script using PHP. Server-side processing scripts can be written in any language, using the protocol described in the DataTables documentation.